# Save environment variables
export PROJECT_ID="PROJECT ID"
export ORG_ID="ORGID"
echo "Org ID is: " $ORG_ID
echo "Project is: " $PROJECT_ID

# gcloud must be initilized before executing this script.
echo "===== Sailpoint CAM GCP Init script from PS ====="

# Pass in Argument:
export YAML_FILEPATH="role-definition.yaml"
export SERVICEACCOUNT_NAME="sp-ciem-serviceaccount-gcloud"
export ROLE_NAME="sp_cam_role_gcloud"
export PRIVATEKEY_FILEPATH="sa-private-key.json"

# Create Service Account at Project level. This service account will have the following role assinged to it
echo "===== Creating Service Account ====="
gcloud iam service-accounts create $SERVICEACCOUNT_NAME --description="This Service account is for Sailpoint CAM to read GCP resources" --display-name=$SERVICEACCOUNT_NAME

# Create the Role at the organization level (required) using the supplied role-definition.yaml file (doesn't need to be updated before use)
echo "===== Creating Role ====="
gcloud iam roles create $ROLE_NAME --organization=$ORG_ID --file=$YAML_FILEPATH

# Assign the Role to the service account
echo "===== Assigning Role to Service Account ====="
gcloud organizations add-iam-policy-binding $ORG_ID --member="serviceAccount:$SERVICEACCOUNT_NAME@$PROJECT_ID.iam.gserviceaccount.com" --role=organizations/$ORG_ID/roles/$ROLE_NAME

# Create the JSON key, save file to working directory
echo "===== Generating Service Account Key ====="
gcloud iam service-accounts keys create $PRIVATEKEY_FILEPATH --iam-account=$SERVICEACCOUNT_NAME@$PROJECT_ID.iam.gserviceaccount.com

# Enable the APIs for CAM Service Account to call, this can take a few minutes
echo "===== Enable APIs ====="
gcloud services enable compute.googleapis.com bigtableadmin.googleapis.com cloudfunctions.googleapis.com sqladmin.googleapis.com logging.googleapis.com iam.googleapis.com cloudresourcemanager.googleapis.com admin.googleapis.com cloudkms.googleapis.com bigquery.googleapis.com
